@@ -64,11 +64,15 @@ pub struct Session {
     /// The backends configured for this execution.
     ///
     /// Populated prior to guest execution, and never modified.
-    pub(crate) backends: Arc<Backends>,
+    backends: Arc<Backends>,
+    /// The TLS configuration for this execution.
+    ///
+    /// Populated prior to guest execution, and never modified.
+    tls_config: Arc<rustls::ClientConfig>,
     /// The dictionaries configured for this execution.
     ///
     /// Populated prior to guest execution, and never modified.
-    pub(crate) dictionaries: Arc<Dictionaries>,
+    dictionaries: Arc<Dictionaries>,
     /// The dictionaries configured for this execution.
     ///
     /// Populated prior to guest execution, and never modified.
@@ -76,19 +80,21 @@ pub struct Session {
     /// The path to the configuration file used for this invocation of Viceroy.
     ///
     /// Created prior to guest execution, and never modified.
-    pub(crate) config_path: Arc<Option<PathBuf>>,
+    config_path: Arc<Option<PathBuf>>,
     /// The ID for the client request being processed.
     req_id: u64,
 }
 
 impl Session {
     /// Create an empty session.
+    #[allow(clippy::too_many_arguments)]
     pub fn new(
         req_id: u64,
         req: Request<Body>,
         resp_sender: Sender<Response<Body>>,
         client_ip: IpAddr,
         backends: Arc<Backends>,
+        tls_config: Arc<rustls::ClientConfig>,
         dictionaries: Arc<Dictionaries>,
         config_path: Arc<Option<PathBuf>>,
     ) -> Session {
@@ -113,6 +119,7 @@ impl Session {
             log_endpoints: PrimaryMap::new(),
             log_endpoints_by_name: HashMap::new(),
             backends,
+            tls_config,
             dictionaries,
             dictionaries_by_name: PrimaryMap::new(),
             config_path,
@@ -134,6 +141,7 @@ impl Session {
             sender,
             "0.0.0.0".parse().unwrap(),
             Arc::new(HashMap::new()),
+            Arc::new(rustls::ClientConfig::new()),
             Arc::new(HashMap::new()),
             Arc::new(None),
         )
@@ -512,6 +520,18 @@ impl Session {
         self.backends.get(name).map(std::ops::Deref::deref)
     }
 
+    /// Access the backend map.
+    pub fn backends(&self) -> &Arc<Backends> {
+        &self.backends
+    }
+
+    // ----- TLS config -----
+
+    /// Access the TLS configuration.
+    pub fn tls_config(&self) -> &Arc<rustls::ClientConfig> {
+        &self.tls_config
+    }
+
     // ----- Dictionaries API -----
 
     /// Look up a dictionary-handle by name.
@@ -528,6 +548,11 @@ impl Session {
             .ok_or(HandleError::InvalidDictionaryHandle(handle))
     }
 
+    /// Access the dictionary map.
+    pub fn dictionaries(&self) -> &Arc<Dictionaries> {
+        &self.dictionaries
+    }
+
     // ----- Pending Requests API -----
 
     /// Insert a [`PendingRequest`] into the session.
@@ -626,6 +651,11 @@ impl Session {
     pub fn req_id(&self) -> u64 {
         self.req_id
     }
+
+    /// Access the path to the configuration file for this invocation.
+    pub fn config_path(&self) -> &Arc<Option<PathBuf>> {
+        &self.config_path
+    }
 }
 
 #[derive(Clone, Copy, Eq, Hash, PartialEq)]
